# goldilock


[![image](https://img.shields.io/pypi/v/goldilock.svg)](https://pypi.python.org/pypi/goldilock)
[![image](https://img.shields.io/conda/vn/conda-forge/goldilock.svg)](https://anaconda.org/conda-forge/goldilock)


**A basic python package**


-   Free software: MIT license
-   Documentation: https://NandhiniKRC.github.io/goldilock
    

## Features

-   TODO
